<?php

namespace Drupal\mcp\ResponseHandler;

use Drupal\mcp\Storage\ClientMessageStorageInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Handles the SSE response from the MCP server.
 */
class SseResponseHandler implements ResponseHandlerInterface {

  public function __construct(
    private readonly ClientMessageStorageInterface $storage,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function handleResponse(
    $rpcResponse,
    ?string $clientId = NULL,
  ): JsonResponse {
    if (!$clientId) {
      throw new \Exception('Client ID is required');
    }

    if (!$this->storage->isClientConnected($clientId)) {
      throw new \Exception('Client is not connected');
    }

    $this->storage->storeMessage($clientId, $rpcResponse->getContent());

    return new JsonResponse(['status' => 'ok']);
  }

}
