<?php

namespace Drupal\mcp\Storage;

/**
 * Interface for storing messages for clients.
 */
interface ClientMessageStorageInterface {

  /**
   * Check if a client is connected.
   *
   * @param string $clientId
   *   The client ID.
   *
   * @return bool
   *   TRUE if the client is connected, FALSE otherwise.
   *
   * @throws \Exception
   */
  public function isClientConnected(string $clientId): bool;

  /**
   * Connect a client.
   *
   * @param string $clientId
   *   The client ID.
   *
   * @throws \Exception
   */
  public function connectClient(string $clientId): void;

  /**
   * Disconnect a client.
   *
   * @param string $clientId
   *   The client ID.
   *
   * @throws \Exception
   */
  public function disconnectClient(string $clientId): void;

  /**
   * Store a message for a client.
   *
   * @param string $clientId
   *   The client ID.
   * @param string $message
   *   The message.
   *
   * @throws \Exception
   */
  public function storeMessage(string $clientId, string $message): void;

  /**
   * Get a message for a client.
   *
   * @param string $clientId
   *   The client ID.
   *
   * @return mixed
   *   The message.
   *
   * @throws \Exception
   */
  public function getMessage(string $clientId): mixed;

  /**
   * Delete a message for a client.
   *
   * @param string $clientId
   *   The client ID.
   *
   * @throws \Exception
   */
  public function deleteMessage(string $clientId): void;

}
